==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QPropertyBindingError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qproperty.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPropertyBindingError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPropertyBindingError")
    QPropertyBindingError *_ptr = reinterpret_cast<QPropertyBindingError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPropertyBindingError()
void __qt_construct_QPropertyBindingError_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError()")
    Q_UNUSED(__java_arguments)
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QPropertyBindingError(QPropertyBindingError)
void __qt_construct_QPropertyBindingError_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError(QPropertyBindingError)")
    jobject other0 = __java_arguments[0].l;
    const QPropertyBindingError& __qt_other0 = qtjambi_cast<const QPropertyBindingError& >(__jni_env, other0);
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QPropertyBindingError(QPropertyBindingError::Type,QString)
void __qt_construct_QPropertyBindingError_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError(QPropertyBindingError::Type,QString)")
    jobject type0 = __java_arguments[0].l;
    QPropertyBindingError::Type __qt_type0 = qtjambi_cast<QPropertyBindingError::Type>(__jni_env, type0);
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError(QPropertyBindingError::Type(__qt_type0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QPropertyBindingError(QPropertyBindingError::Type,QString)
void __qt_construct_QPropertyBindingError_3(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError(QPropertyBindingError::Type,QString)")
    jobject type0 = __java_arguments[0].l;
    QPropertyBindingError::Type __qt_type0 = qtjambi_cast<QPropertyBindingError::Type>(__jni_env, type0);
    jstring description1 = static_cast<jstring>(__java_arguments[1].l);
    QString  __qt_description1 = qtjambi_cast<QString>(__jni_env, description1);
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError(QPropertyBindingError::Type(__qt_type0), __qt_description1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPropertyBindingError
void __qt_destruct_QPropertyBindingError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPropertyBindingError")
    reinterpret_cast<QPropertyBindingError*>(ptr)->~QPropertyBindingError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPropertyBindingError::QPropertyBindingError()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_initialize_1native__Lio_qt_core_QPropertyBindingError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyBindingError::QPropertyBindingError()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyBindingError_0, sizeof(QPropertyBindingError), typeid(QPropertyBindingError), false, &deleter_QPropertyBindingError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPropertyBindingError::QPropertyBindingError(QPropertyBindingError)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_initialize_1native__Lio_qt_core_QPropertyBindingError_2Lio_qt_core_QPropertyBindingError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyBindingError::QPropertyBindingError(QPropertyBindingError)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyBindingError_1, sizeof(QPropertyBindingError), typeid(QPropertyBindingError), false, &deleter_QPropertyBindingError, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPropertyBindingError::QPropertyBindingError(QPropertyBindingError::Type,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_initialize_1native__Lio_qt_core_QPropertyBindingError_2Lio_qt_core_QPropertyBindingError_00024Type_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jstring description1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyBindingError::QPropertyBindingError(QPropertyBindingError::Type,QString)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].l = description1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyBindingError_3, sizeof(QPropertyBindingError), typeid(QPropertyBindingError), false, &deleter_QPropertyBindingError, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPropertyBindingError::description()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_description_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::description()const", __qt_this)
        QString __qt_return_value = __qt_this->description();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPropertyBindingError::hasError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_hasError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::hasError()const", __qt_this)
        __java_return_value = __qt_this->hasError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPropertyBindingError::operator=(QPropertyBindingError)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_assign_1native_1cref_1QPropertyBindingError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::operator=(QPropertyBindingError)", __qt_this)
        const QPropertyBindingError& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPropertyBindingError>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPropertyBindingError::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::type()const", __qt_this)
        QPropertyBindingError::Type __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPropertyBindingError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPropertyBindingError>("QPropertyBindingError", "io/qt/core/QPropertyBindingError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPropertyBindingError, {
        ConstructorInfo(&__qt_construct_QPropertyBindingError_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPropertyBindingError_1, "Lio/qt/core/QPropertyBindingError;")
       ,ConstructorInfo(&__qt_construct_QPropertyBindingError_2, "Lio/qt/core/QPropertyBindingError$Type;")
       ,ConstructorInfo(&__qt_construct_QPropertyBindingError_3, "Lio/qt/core/QPropertyBindingError$Type;Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPropertyBindingError);
    registerMetaType<QPropertyBindingError>("QPropertyBindingError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QPropertyBindingError::Type>("QPropertyBindingError::Type", "io/qt/core/QPropertyBindingError$Type");
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QPropertyBindingError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qproperty.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPropertyBindingError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPropertyBindingError")
    QPropertyBindingError *_ptr = reinterpret_cast<QPropertyBindingError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPropertyBindingError()
void __qt_construct_QPropertyBindingError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError()")
    Q_UNUSED(__java_arguments)
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPropertyBindingError::QPropertyBindingError()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_initialize_1native__Lio_qt_core_QPropertyBindingError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyBindingError::QPropertyBindingError()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyBindingError, sizeof(QPropertyBindingError), typeid(QPropertyBindingError), false, &deleter_QPropertyBindingError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPropertyBindingError(QPropertyBindingError)
void __qt_construct_QPropertyBindingError_cref_QPropertyBindingError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError(QPropertyBindingError)")
    jobject other0 = __java_arguments[0].l;
    const QPropertyBindingError& __qt_other0 = qtjambi_cast<const QPropertyBindingError& >(__jni_env, other0);
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPropertyBindingError::QPropertyBindingError(QPropertyBindingError)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_initialize_1native__Lio_qt_core_QPropertyBindingError_2Lio_qt_core_QPropertyBindingError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyBindingError::QPropertyBindingError(QPropertyBindingError)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyBindingError_cref_QPropertyBindingError, sizeof(QPropertyBindingError), typeid(QPropertyBindingError), false, &deleter_QPropertyBindingError, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPropertyBindingError(QPropertyBindingError::Type,QString)
void __qt_construct_QPropertyBindingError_QPropertyBindingError_Type(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError(QPropertyBindingError::Type,QString)")
    jobject type0 = __java_arguments[0].l;
    QPropertyBindingError::Type __qt_type0 = qtjambi_cast<QPropertyBindingError::Type>(__jni_env, type0);
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError(QPropertyBindingError::Type(__qt_type0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QPropertyBindingError(QPropertyBindingError::Type,QString)
void __qt_construct_QPropertyBindingError_QPropertyBindingError_Type_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyBindingError(QPropertyBindingError::Type,QString)")
    jobject type0 = __java_arguments[0].l;
    QPropertyBindingError::Type __qt_type0 = qtjambi_cast<QPropertyBindingError::Type>(__jni_env, type0);
    jstring description1 = static_cast<jstring>(__java_arguments[1].l);
    QString  __qt_description1 = qtjambi_cast<QString>(__jni_env, description1);
    QPropertyBindingError *__qt_this = new(__qtjambi_ptr) QPropertyBindingError(QPropertyBindingError::Type(__qt_type0), __qt_description1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPropertyBindingError::QPropertyBindingError(QPropertyBindingError::Type,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_initialize_1native__Lio_qt_core_QPropertyBindingError_2Lio_qt_core_QPropertyBindingError_00024Type_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jstring description1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyBindingError::QPropertyBindingError(QPropertyBindingError::Type,QString)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].l = description1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyBindingError_QPropertyBindingError_Type_cref_QString, sizeof(QPropertyBindingError), typeid(QPropertyBindingError), false, &deleter_QPropertyBindingError, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPropertyBindingError
void __qt_destruct_QPropertyBindingError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPropertyBindingError")
    reinterpret_cast<QPropertyBindingError*>(ptr)->~QPropertyBindingError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPropertyBindingError::description()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_description_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::description()const", __qt_this)
        QString __qt_return_value = __qt_this->description();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPropertyBindingError::hasError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_hasError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::hasError()const", __qt_this)
        __java_return_value = __qt_this->hasError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPropertyBindingError::operator=(QPropertyBindingError)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_assign_1native_1cref_1QPropertyBindingError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::operator=(QPropertyBindingError)", __qt_this)
        const QPropertyBindingError& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QPropertyBindingError>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPropertyBindingError::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyBindingError::type()const", __qt_this)
        QPropertyBindingError::Type __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyBindingError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPropertyBindingError *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyBindingError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPropertyBindingError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPropertyBindingError>("QPropertyBindingError", "io/qt/core/QPropertyBindingError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPropertyBindingError, {
        ConstructorInfo(&__qt_construct_QPropertyBindingError, nullptr)
       ,ConstructorInfo(&__qt_construct_QPropertyBindingError_cref_QPropertyBindingError, "Lio/qt/core/QPropertyBindingError;")
       ,ConstructorInfo(&__qt_construct_QPropertyBindingError_QPropertyBindingError_Type, "Lio/qt/core/QPropertyBindingError$Type;")
       ,ConstructorInfo(&__qt_construct_QPropertyBindingError_QPropertyBindingError_Type_cref_QString, "Lio/qt/core/QPropertyBindingError$Type;Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPropertyBindingError);
    registerMetaType<QPropertyBindingError>("QPropertyBindingError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QPropertyBindingError::Type>("QPropertyBindingError::Type", "io/qt/core/QPropertyBindingError$Type");
// END: enums and flags
}
